@@ -20,7 +20,7 @@ package Getopt::MySimple;
 
 # --------------------------------------------------------------------------
 # Locally modified by obachman (Display type instead of env, order by cmp)
-# $Id: MySimple.pm,v 1.2 2001/05/01 14:43:48 dprice Exp $
+# $Id: MySimple.pm,v 1.6 2008/11/26 19:09:01 pertusus Exp $
 
 # use strict;
 # no strict 'refs';
@@ -94,7 +94,7 @@ sub getOptions
 	  { 
 	   type => ':i', 
 	   default => '',
-	   linkage => sub {$self->helpOptions($_[1]); exit (0) if $helpThenExit;},
+	   linkage => sub {$self->helpOptions($_[1]); sleep 5;exit (0) if $helpThenExit;},
 	   verbose => "print help and exit"
 	  };
 	}
@@ -112,6 +112,7 @@ sub getOptions
 
 	for (keys(%{$self -> {'default'} }) )
 	{
+	  next unless (ref(${$self -> {'default'} }{$_}) eq 'HASH');
 	  my $type = ${$self -> {'default'} }{$_}{'type'};
 	  push(@{$self -> {'type'} }, "$_$type");
 	  $self->{'opt'}->{$_} =  ${$self -> {'default'} }{$_}{'linkage'}
@@ -158,13 +159,13 @@ sub helpOptions
           #$line = " -$_" . ' ' x ($optwidth - (2 + length) ) .
           #      	"${$self->{'default'} }{$_}{'type'} ".
           #      	' ' x ($typewidth - (1+length(${$self -> {'default'} }{$_}{'type'}) ));
-		$line = " -$_" . "${$self->{'default'} }{$_}{'type'}".
+		$line = " --$_" . "${$self->{'default'} }{$_}{'type'}".
 			' ' x ($typewidth - (1+length(${$self -> {'default'} }{$_}{'type'}) ));
 
                  $val = ${$self->{'default'} }{$_}{'linkage'};
                 if ($val)
                 {
-                  if (ref($val) eq 'SCALAR')
+                  if ((ref($val) eq 'SCALAR') and (defined($$val)))
 		  {
 		    $val = $$val; 
 		  }
@@ -173,10 +174,14 @@ sub helpOptions
 		    $val = '';
 		  }
                 }
-		else
+		elsif (defined(${$self->{'default'} }{$_}{'default'}))
 		{
 		  $val = ${$self->{'default'} }{$_}{'default'};
 		}
+		else
+		{
+		  $val = '';
+		}
 	        $line .= "$val  ";
 		$line .= ' ' x ($optwidth + $typewidth + $defaultwidth + 1 - length($line));
 		
@@ -206,7 +211,8 @@ sub helpOptions
 	}
 
 	print <<EOT;
-Note: 'Options' may be abbreviated. 'Type' specifications mean:
+Note: 'Options' may be abbreviated. -- prefix may be replaced by a single -.
+'Type' specifications mean:
  <none>| !    no argument: variable is set to 1 on -foo (or, to 0 on -nofoo)
     =s | :s   mandatory (or, optional)  string argument
     =i | :i   mandatory (or, optional)  integer argument
