@@ -8,7 +8,7 @@ aclocal
 
 # Create `Makefile.in' from `Makefile.am', and symlink `install-sh',
 # `missing' and `mkinstalldirs' from /usr/share/automake.
-automake --add-missing Makefile
+automake --add-missing 
 
 # Create `configure' from `configure.in'.
 autoconf
